Clazz.declarePackage("J.api");
Clazz.declareInterface(J.api, "GenericMouseInterface");
;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
